import Api from "../../api/api"
export default {
    namespaced: true,
    state: {
        bindData: {},
        pageInfo: {},
        branchBank: {},
        isQuerying: true,
        loginInfo: null, // 登录信息
        accessToken: null, // 用户令牌
        goodsInfo: null,// 商品信息
        menuPermissions: null,// 权限
        goodsOptional: null// 自选
    },
    getters: {
        loginInfo: state => state.loginInfo,
        accessToken: state => state.accessToken,
        goodsInfo: state => state.goodsInfo,
        goodsOptional: state => state.goodsOptional
    },
    mutations: {
        setBindData(state, data) {
            state.bindData = data
        },
        setPageInfo(state, page) {
            state.pageInfo = page
        },
        setBranchBank(state, bank) {
            state.branchBank = bank
        },
        clearStore(state) {
            state.bindData = {}
            state.pageInfo = {}
            state.branchBank = {}
        },
        setIsQuerying(state, qry) {
            state.isQuerying = qry
        },
        setLoginInfo (state, data) {
            state.loginInfo = data
        },
        setAccessToken (state, data) {
            state.accessToken = data
        },
        // 商品信息
        setGoodsInfo (state, data) {
            state.goodsInfo = data
        },
        // clearStore (state, key) {
        //     state[key] = null
        // },
        setMenuPermissions (state, data) {
            state.menuPermissions = data
        },
        setGoodsOptional (state, data) {
            state.goodsOptional = data
        }
    },
    actions: {
        setLoginInfo ({ commit }, data) {
            commit('setLoginInfo', data)
        },
        setAccessToken ({ commit }, data) {
            commit('setAccessToken', data)
        },
        setGoodsInfo ({ commit }, data) {
            commit('setGoodsInfo', data)
        },
        clearStore ({ commit }, key) {
            commit('clearStore', key)
        },
        setMenuPermissions ({ commit }, data) {
            commit('setMenuPermissions', data)
        },
        setGoodsOptional ({ commit }, data) {
            commit('setGoodsOptional', data)
        },
        qryBranchBank({commit, dispatch}, option) {
            return new Promise((resolve, reject) => {
                Api.qryBranchBank(option).then(r => {
                    commit('setIsQuerying', false)
                    if (isFailure(r, reject)) {
                       return false
                    }
                    const res = r.data[0], pageInfo = {}
                    pageInfo.totalItem = Number(res.total_item) || 0
                    if (res.items && res.items.length) {
                        // 更新现有数据
                        pageInfo.branchItems = res.items
                    }
                    pageInfo.pageNo = ++(option.current_page)
                    commit('setPageInfo', pageInfo)
                    resolve(pageInfo)
                }).catch(e => {
                    reject(e)
                })
            })
        }
    }
  }

  const isFailure = (r, reject) => {
    if (!r || r === 'error') {
        reject()
        return true
    }
    if (!r.data || !r.data[0]) {
        reject(r.error_info)
        return true
    }
    const res = r.data[0]
    if (res.error_no && res.error_no !== "0") {
        reject(res.error_info)
        return true
    }
    return false
}